pub struct Proposal<T>where
T: NodeType,{
pub block_header: <T as NodeType>::BlockHeader,
pub view_number: ViewNumber,
pub epoch: EpochNumber,
pub justify_qc: SimpleCertificate<T, QuorumData2<T>, SuccessThreshold>,
pub next_epoch_justify_qc: Option<SimpleCertificate<T, Vote2Data<T>, SuccessThreshold>>,
pub upgrade_certificate: Option<SimpleCertificate<T, UpgradeProposalData, UpgradeThreshold>>,
pub view_change_evidence: Option<SimpleCertificate<T, TimeoutData2, SuccessThreshold>>,
pub next_drb_result: Option<[u8; 32]>,
pub state_cert: Option<LightClientStateUpdateCertificateV2<T>>,
}Expand description
Proposal to append a block.
Fields
block_header: <T as NodeType>::BlockHeaderThe block header to append
view_number: ViewNumberview number for the proposal
epoch: EpochNumberThe epoch number corresponding to the block number.
justify_qc: SimpleCertificate<T, QuorumData2<T>, SuccessThreshold>certificate that the proposal is chaining from
next_epoch_justify_qc: Option<SimpleCertificate<T, Vote2Data<T>, SuccessThreshold>>certificate proving the last block of the epoch is decided
upgrade_certificate: Option<SimpleCertificate<T, UpgradeProposalData, UpgradeThreshold>>Possible upgrade certificate, which the leader may optionally attach.
view_change_evidence: Option<SimpleCertificate<T, TimeoutData2, SuccessThreshold>>Possible timeout certificate.
If the justify_qc is not for a proposal in the immediately preceding
view, then a timeout certificate must be attached.
next_drb_result: Option<[u8; 32]>The DRB result for the next epoch.
This is required only for the last block of the epoch. Nodes will verify that it’s consistent with the result from their computations.
state_cert: Option<LightClientStateUpdateCertificateV2<T>>The light client state update certificate for the next epoch. This is required for the epoch root.